Learn R Programming

matchbook (version 1.0.7)

mb_get_balance: Get List of Current Bets on Matchbook

Description

Get account balance/exposure etc.

Usage

mb_get_balance(session_data)

Arguments

session_data

A session object returned from a successful mb_login attempt. It contains details about your user preferences and security details.

Value

If successful, a list with account balance information. The data frame has the following fields:

id

the account id

balance

the account balance in the currency of the account

exposure

the account exposure in the currency of the account

commission-reserve

the commission-reserve in the currency of the account

free-funds

the free-funds in the currency of the account

See Also

mb_login

Examples

Run this code
# NOT RUN {
my_session <- mb_login("my_user_name","my_password"); 
mb_get_balance(session_data=my_session)
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab