A session object returned from a successful mb_login attempt. It contains details about your user preferences and security details.
sport_ids
A vector of integer sport_ids that indicate sports for which event details are required. e.g. c(15,1) gives Soccer and Pro Football (NFL)
start_date
A string (or date/POSIXct) value with format YYYY-mm-dd or YYYY-mm-dd HH:MM:SS format.
end_date
A string (or date/POSIXct) value with format YYYY-mm-dd or YYYY-mm-dd HH:MM:SS format.
market_states
A vector of string containing the market states to return. Defaults to 'open' or 'suspended' market types.
Value
If successful, a dataframe with first 500 events and associated information. Only 500 events are permitted at one time. Pagination is possible but not implemented in this version.
The data frame has the following fields:
id
Event id
name
Event name
start
The start date of the event
status
If betting is still available on this event it will have status='open'
sport-id
The sport id of this event
category-id
The category of the event e.g. Premier League is a category within Football/Soccer