powered by
List the Runners Available on Matchbook.com for a given Market
mb_get_runners(session_data, event_id, market_id, runner_id = NULL, runner_states = c("open", "suspended"), include_prices = TRUE, side = NULL, include_withdrawn = TRUE)
A session object returned from a successful mb_login attempt. It contains details about your user preferences and security details.
The event_id integer for the associated market.
The market_id integer for which a list of associated runners is required.
If you only require details for a single runner, specify this optional runner_id integer.
A vector of string containing the runner states to return. Defaults to 'open' or 'suspended' market types.
A boolean for returning runner prices in the response. Defaults to TRUE.
A filter to view the selected 'back' or 'lay' prices. The default is to return both.
A boolean for returning or not the withdrawn runners in the response. Defaults to TRUE.
If successful, a dataframe with associated runner information. The data frame has the following fields:
Runner name
If betting is still available on this runner, it will have status='open'
Event id
Runner id
Market id
If include_prices=TRUE then available prices for each runner are returned nested within the data frame.
mb_get_sports,mb_get_events,mb_get_markets
# NOT RUN { my_session <- mb_login("my_user_name","my_password"); mb_get_runners(session_data=my_session,event_id=123456,market_id=1234567) # } # NOT RUN { # }
Run the code above in your browser using DataLab