A session object returned from a successful mb_login attempt. It contains details about your user preferences and security details.
sport_id
A vector of integer sport_ids that indicated sports for which event details are required. e.g. c(15,1) gives Soccer and Pro Football (NFL)
period
A value with one of 'today', '1-day', '2-day', 'yesterday', 'week', 'month', '1-month', '3-month'
start_date
A string (or date/POSIXct) value with format YYYY-mm-dd or YYYY-mm-dd HH:MM:SS format. Defaults to 90 days ago.
end_date
A string (or date/POSIXct) value with format YYYY-mm-dd or YYYY-mm-dd HH:MM:SS format. Defaults to today.
Value
If successful, a dataframe with first 500 settled bets. Only 500 bets are permitted at one time. Pagination is possible but not implemented in this version.
The data frame has the following fields: