Learn R Programming

matchbook (version 1.0.7)

mb_get_sports: Get List of Available Sports

Description

List the Sports currently available on Matchbook.com.

Usage

mb_get_sports(session_data, nsports = 1000)

Arguments

session_data

A session object returned from a successful mb_login attempt. It contains security details and your account preferences.

nsports

The number of sports for which details are required. Default is 1000.

Value

If successful, a data frame with the following fields:

name

sport name

type

the type of the sport

id

sport id

See Also

mb_get_events

Examples

Run this code
# NOT RUN {
my_session <- mb_login("my_user_name","versafepassword"); 
mb_get_sports(session_data=my_session)
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab