Learn R Programming

matchbook (version 1.0.7)

mb_login: Login and Authenticate with the Matchbook.com API

Description

Validate your session with the Matchbook API.

Usage

mb_login(username, password, print_balance_details = TRUE)

Arguments

username

Your Matchbook.com username. If you are not already registered go to Matchbook.com.

password

The password set by you during the registration process.

print_balance_details

optional parameter to allow balance and exposure display at the time of login

Value

A list with status_code and other fields relating to your session and account. If the log-in is successful, a status_code of 200 is returned.

See Also

mb_logout

Examples

Run this code
# NOT RUN {
mb_login("my_username","verysafepassword")
# }

Run the code above in your browser using DataLab