Learn R Programming

matchbook (version 1.0.7)

mb_logout: Terminate a Matchbook.com API session

Description

End the Matchbook.com session.

Usage

mb_logout(session_data)

Arguments

session_data

This is a required parameter containing security and preference information. It must take the exact format of the object returned by the mb_login request.

Value

The response integer status_code.

See Also

mb_login

Examples

Run this code
# NOT RUN {
my_session <- mb_login("my_user_name","verysafepassword"); 
mb_logout(my_session)
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab