powered by
Get account balance/exposure etc.
mb_get_balance(session_data)
A session object returned from a successful mb_login attempt. It contains details about your user preferences and security details.
If successful, a list with account balance information. The data frame has the following fields:
the account id
the account balance in the currency of the account
the account exposure in the currency of the account
the commission-reserve in the currency of the account
the free-funds in the currency of the account
mb_login
# NOT RUN { my_session <- mb_login("my_user_name","my_password"); mb_get_balance(session_data=my_session) # } # NOT RUN { # }
Run the code above in your browser using DataLab