powered by
List the Sports currently available on Matchbook.com.
mb_get_sports(session_data, nsports = 1000)
A session object returned from a successful mb_login attempt. It contains security details and your account preferences.
mb_login
The number of sports for which details are required. Default is 1000.
If successful, a data frame with the following fields:
sport name
the type of the sport
sport id
mb_get_events
# NOT RUN { my_session <- mb_login("my_user_name","versafepassword"); mb_get_sports(session_data=my_session) # } # NOT RUN { # }
Run the code above in your browser using DataLab