powered by
Validate your session with the Matchbook API.
mb_login(username, password, print_balance_details = TRUE)
Your Matchbook.com username. If you are not already registered go to Matchbook.com.
The password set by you during the registration process.
optional parameter to allow balance and exposure display at the time of login
A list with status_code and other fields relating to your session and account. If the log-in is successful, a status_code of 200 is returned.
mb_logout
# NOT RUN { mb_login("my_username","verysafepassword") # }
Run the code above in your browser using DataLab