powered by
End the Matchbook.com session.
mb_logout(session_data)
This is a required parameter containing security and preference information. It must take the exact format of the object returned by the mb_login request.
The response integer status_code.
mb_login
# NOT RUN { my_session <- mb_login("my_user_name","verysafepassword"); mb_logout(my_session) # } # NOT RUN { # }
Run the code above in your browser using DataLab